elephant.test.test_spike_train_correlation module — Elephant 0.5.0 documentation

# elephant.test.test_spike_train_correlation module

Unit tests for the spike_train_correlation module.

class `elephant.test.test_spike_train_correlation.` `SpikeTimeTilingCoefficientTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_exist_alias`()
  `test_sttc`()

class `elephant.test.test_spike_train_correlation.` `corrcoeff_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_corrcoef_binned`()

    Test the correlation coefficient between two binned spike trains.

  `test_corrcoef_binned_same_spiketrains`()

    Test if the correlation coefficient between two identical binned spike trains evaluates to a 2x2 matrix of ones.

  `test_corrcoef_binned_short_input`()

    Test if input list of one binned spike train yields 1.0.

class `elephant.test.test_spike_train_correlation.` `covariance_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_covariance_binned`()

    Test covariance between two binned spike trains.

  `test_covariance_binned_same_spiketrains`()

    Test if the covariation between two identical binned spike trains evaluates to the expected 2x2 matrix.

  `test_covariance_binned_short_input`()

    Test if input list of only one binned spike train yields correct result that matches numpy.cov (covariance with itself)

class `elephant.test.test_spike_train_correlation.` `cross_correlation_histogram_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_border_correction`()

    Test if the border correction for bins at the edges is correctly performed

  `test_cross_correlation_histogram`()

    Test generic result of a cross-correlation histogram between two binned spike trains.

  `test_exist_alias`()

    Test if alias cch still exists.

  `test_kernel`()

    Test if the smoothing kernel is correctly defined, and wheter it is applied properly.

  `test_raising_error_wrong_inputs`()

    Check that an exception is thrown if the two spike trains are not fullfilling the requirement of the function

  `test_window`()

    Test if the window parameter is correctly interpreted.